import type { MaintStVO } from './model';

import type { ID, IDS } from '#/api/common';

import { commonExport } from '#/api/helper';
import { requestClient } from '#/api/request';

enum Api {
  maintStExport = '/eims/maintSt/export',
  maintStList = '/eims/maintSt/list',
  root = '/eims/maintSt'
}

/**
 * 查询保养汇总列表
 * @param query
 * @returns {*}
 */

export function listMaintSt(params?: any) {
  return requestClient.get<MaintStVO[]>(Api.maintStList, { params });
}


/**
 * 查询保养汇总详细
 * @param maintStId
 */
export function getMaintSt(maintStId: ID) {
  return requestClient.get<MaintStVO>(`${Api.root}/${maintStId}`);
}

/**
 * 新增保养汇总
 * @param data
 */
export function addMaintSt(data: any) {
  return requestClient.postWithMsg<void>(Api.root, data);
}

/**
 * 修改保养汇总
 * @param data
 */
export function updateMaintSt(data: any) {
  return requestClient.putWithMsg<void>(Api.root, data);
}

/**
 * 删除保养汇总
 * @param maintStId
 */
export function delMaintSt(maintStId: IDS) {
  return requestClient.deleteWithMsg<void>(`${Api.root}/${maintStId}`);
}
/**
 * 导出
 * @param
 */
export function maintStExport(data: any) {
  return commonExport(Api.maintStExport, data);
}
